# ADR Template

## Title

Short title of the decision

## Status

- Proposed / Accepted / Deprecated / Superseded by [ADR-XXXX](adr-XXXX.md)

## Context

What is the issue that we're seeing that is motivating this decision or change?

## Decision

What is the change that we're proposing or have agreed to implement?

## Consequences

What becomes easier or more difficult to do because of this change?

### Positive

- Benefit 1
- Benefit 2

### Negative

- Drawback 1
- Drawback 2

### Neutral

- Observation 1

## Alternatives Considered

What other options were considered and why were they rejected?

### Alternative 1

Why it was not chosen

### Alternative 2

Why it was not chosen

## References

- Links to related documents
- Related ADRs
- External resources
